@@ -17,9 +17,9 @@ API_KEY = ''
 
 API_TOKEN = 'WAVELETAI_TOKEN'
 
-USER_NAME = 'WAVELETAI_USERNAME'
+API_MODEL= 'WAVELETAI_MODEL'
 
-USER_PWD = 'WAVELETAI_PASSWORD'
+API_PROJ = 'WAVELETAI_PROJ'
 
 """单次请求最大值"""
 CHUNK_SIZE = 1024
